| Title: | Tools for interacting with Techtonique API |
|---|---|
| Description: | High level R functions for interacting with Techtonique forecasting API. |
| Authors: | T. Moudiki |
| Maintainer: | T. Moudiki <[email protected]> |
| License: | MIT |
| Version: | 0.4.0 |
| Built: | 2026-05-21 07:14:23 UTC |
| Source: | https://github.com/Techtonique/forecastingAPI_r |
Obtain forecasts from a csv file
get_forecast( path_to_file, base_model = "RidgeCV", n_hidden_features = 5L, lags = 25L, type_pi = "gaussian", replications = NULL, h = 10L )get_forecast( path_to_file, base_model = "RidgeCV", n_hidden_features = 5L, lags = 25L, type_pi = "gaussian", replications = NULL, h = 10L )
path_to_file |
a string; path to csv file containing time series data (examples: https://github.com/Techtonique/datasets/tree/main/time_series/univariate) |
base_model |
a string; Forecasting method to use (default is "RidgeCV"); for now scikit-learn model names. |
|
an integer; Number of hidden features for the model (default is 5). |
|
lags |
an integer; Number of lags to use in the model (default is 25). |
type_pi |
a string; Type of prediction interval to use (default is 'gaussian'). |
replications |
an integer; Number of replications for certain methods (default is None). |
h |
an integer; Forecast horizon (default is 10). |